@@ -6,7 +6,7 @@
     This script is a stand-alone application, and can be run from anywhere with a connection to the internet.
     It runs on either unix or windows.  It requires only the MadrigalWeb python module to be installed.
 
-$Id: globalDownload.py 5726 2016-06-17 14:19:18Z brideout $
+$Id: globalDownload.py 6100 2017-06-07 15:15:03Z brideout $
 """
 
 usage = """
@@ -766,12 +766,13 @@ for i in range(numFiles):
         # add number
         count = 1
         while(True):
-            newName = saveName[0:saveName.rfind('.')] + '_0' + saveName[saveName.rfind('.'):]
+            newName = saveName[0:saveName.rfind('.')] + '_%i' % (count-1) + saveName[saveName.rfind('.'):]
             if not os.access(newName, os.R_OK):
                 saveName = newName
                 break
             else:
                 count += 1
+
     try:
         server.downloadFile(expFileList[i].name, saveName,
                             user_fullname, user_email, user_affiliation,
