@@ -5,7 +5,7 @@
     This script is a stand-alone application, and can be run from anywhere with a connection to the internet.
     It runs on either unix or windows.  It requires only the MadrigalWeb python module to be installed.
 
-$Id: globalIsprint.py 5726 2016-06-17 14:19:18Z brideout $
+$Id: globalIsprint.py 5863 2016-10-07 20:11:15Z brideout $
 """
 
 usage = """
@@ -99,6 +99,8 @@ usage = """
 
         --showSummary - if given, summarize all arguments at the beginning.  Not used if format in <Hdf5, netCDF4).
             Default is to not show summary.
+            
+        --hideParms - if given, do not print line at top with requested parms. Default is to print parms at top.
         
         --includeNonDefault - if given, include realtime files when there are no default.  Not used if format in <Hdf5, netCDF4).
             Default is to search only default files.
@@ -599,6 +601,7 @@ longarglist = ['url=',
                'seasonalEndDate=',
                'showFiles',
                'showSummary',
+               'hideParms',
                'includeNonDefault',
                'missing=',
                'assumed=',
@@ -629,6 +632,7 @@ seasonalEndDate = '12/31'
 showFiles = 0
 includeNonDefault = 0
 showSummary = 0
+hideParms = False
 missing = 'missing'
 assumed = 'assumed'
 knownbad = 'knownbad'
@@ -684,6 +688,8 @@ for opt in optlist:
         includeNonDefault = 1
     elif opt[0] == '--showSummary':
         showSummary = 1
+    elif opt[0] == '--hideParms':
+        hideParms = True
     elif opt[0] == '--missing':
         missing = opt[1]
     elif opt[0] == '--assumed':
@@ -865,7 +871,7 @@ if showSummary and (format is None):
     outputFile.write(summary)
 
 # print header if needed
-if format is None:
+if format is None and not hideParms:
     delimiter = '  '
     header = delimiter.join(parms.split(','))
     outputFile.write(header + '\n')
